[open-ils-commits] r12896 - in trunk/Open-ILS/web: css/skin/default js/ui/default/acq/common templates/default/acq/common (erickson)

svn at svn.open-ils.org svn at svn.open-ils.org
Thu Apr 16 16:37:33 EDT 2009


Author: erickson
Date: 2009-04-16 16:37:29 -0400 (Thu, 16 Apr 2009)
New Revision: 12896

Modified:
   trunk/Open-ILS/web/css/skin/default/acq.css
   trunk/Open-ILS/web/js/ui/default/acq/common/li_table.js
   trunk/Open-ILS/web/templates/default/acq/common/li_table.tt2
Log:
more notes tweaks

Modified: trunk/Open-ILS/web/css/skin/default/acq.css
===================================================================
--- trunk/Open-ILS/web/css/skin/default/acq.css	2009-04-16 19:56:16 UTC (rev 12895)
+++ trunk/Open-ILS/web/css/skin/default/acq.css	2009-04-16 20:37:29 UTC (rev 12896)
@@ -102,8 +102,11 @@
 #acq-lit-li-details-table th {padding:0px 3px 1px 3px; font-weight:bold;}
 #acq-lit-li-details-table .dijit {width:130px;}
 #acq-lit-li-details-table td input {width:100px;}
-.acq-lit-note-textarea div { padding: 2px 5px 2px 5px; }
+.acq-lit-note-textarea { border-right: 2px solid #aaa; width:50%;}
+.acq-lit-note-textarea div { padding: 4px; font-weight: bold; }
+#acq-lit-notes-tbody td {padding: 20px 10px 20px 10px; border-bottom:2px solid #aaa;}
 
 .acq-lit-li-menu-bar {width:99%; text-align:left; border:1px solid #aaa; margin:5px 0px 10px 0px;}
 .acq-lit-table-spacer { height:20px; }
 .acq-lit-row td[name="selector"] { width:1.5em; font-weight:bold; color:blue; font-size:110%;}
+

Modified: trunk/Open-ILS/web/js/ui/default/acq/common/li_table.js
===================================================================
--- trunk/Open-ILS/web/templates/default/acq/common/li_table.tt2	2009-04-16 19:56:16 UTC (rev 12895)
+++ trunk/Open-ILS/web/templates/default/acq/common/li_table.tt2	2009-04-16 20:37:29 UTC (rev 12896)
@@ -131,22 +131,22 @@
             </table>
         </div>
 
-        <table class='oils-generic-table'>
+        <table class='oils-generic-table' style='width:90%;'>
             <thead><tr>
+                <th>Note</th>
                 <th>Creator</th>
                 <th>Create Time</th>
                 <th>Editor</th>
                 <th>Edit Time</th>
-                <th>Value</th>
                 <th/>
             </tr></thead>
             <tbody id='acq-lit-notes-tbody'>
                 <tr id='acq-lit-notes-row'>
+                    <td class='acq-lit-note-textarea'><div name='value'/></td>
                     <td><div name='creator'/></td>
                     <td><div name='create_time'/></td>
                     <td><div name='editor'/></td>
                     <td><div name='edit_time'/></td>
-                    <td class='acq-lit-note-textarea'><div name='value'/></td>
                     <td><div name='delete' dojoType='dijit.form.Button' style='color:red;'>X</div></td>
                 </tr>
             </tbody>



More information about the open-ils-commits mailing list
--- trunk/Open-ILS/web/js/ui/default/acq/common/li_table.js	2009-04-16 19:56:16 UTC (rev 12895)
+++ trunk/Open-ILS/web/js/ui/default/acq/common/li_table.js	2009-04-16 20:37:29 UTC (rev 12896)
@@ -138,19 +138,8 @@
     this.addLineitem = function(li) {
         this.liCache[li.id()] = li;
 
-        // sort the lineitem notes on create_time
-        if(li.lineitem_notes()) {
-            li.lineitem_notes(
-                li.lineitem_notes().sort(
-                    function(a, b) { 
-                        if(a.create_time() < b.create_time()) return 1;
-                        return -1;
-                    }
-                )
-            );
-        } else {
-            li.lineitem_notes([]);
-        }
+        // sort the lineitem notes on edit_time
+        if(!li.lineitem_notes()) li.lineitem_notes([]);
 
         var liWrapper = new openils.acq.Lineitem({lineitem:li});
         var row = self.rowTemplate.cloneNode(true);
@@ -183,6 +172,15 @@
     this.drawLiNotes = function(li) {
         var self = this;
 
+        li.lineitem_notes(
+            li.lineitem_notes().sort(
+                function(a, b) { 
+                    if(a.edit_time() < b.edit_time()) return 1;
+                    return -1;
+                }
+            )
+        );
+
         while(this.liNotesTbody.childNodes[0])
             this.liNotesTbody.removeChild(this.liNotesTbody.childNodes[0]);
         this.show('notes');

Modified: trunk/Open-ILS/web/templates/default/acq/common/li_table.tt2
===================================================================